==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf.md <==
# ServiceWebApplicationFirewallPoliciesWaf


```text
azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf
```

```text
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')
```



| Illustration | ServiceWebApplicationFirewallPoliciesWaf | ServiceWebApplicationFirewallPoliciesWafCard | ServiceWebApplicationFirewallPoliciesWafGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf.png) | ![illustration for ServiceWebApplicationFirewallPoliciesWaf](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf.Local.png) | ![illustration for ServiceWebApplicationFirewallPoliciesWafCard](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWafCard.Local.png) | ![illustration for ServiceWebApplicationFirewallPoliciesWafGroup](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWafGroup.Local.png) |




## ServiceWebApplicationFirewallPoliciesWaf

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWaf
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWaf('ServiceWebApplicationFirewallPoliciesWaf', 'Service Web Application Firewall Policies Waf', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWaf
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWaf('ServiceWebApplicationFirewallPoliciesWaf', 'Service Web Application Firewall Policies Waf', 'an optional tech label')
@enduml
```

## ServiceWebApplicationFirewallPoliciesWafCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafCard
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafCard('ServiceWebApplicationFirewallPoliciesWafCard', 'Service Web Application Firewall Policies Waf Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafCard
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafCard('ServiceWebApplicationFirewallPoliciesWafCard', 'Service Web Application Firewall Policies Waf Card', 'an optional description')
@enduml
```

## ServiceWebApplicationFirewallPoliciesWafGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafGroup
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafGroup('ServiceWebApplicationFirewallPoliciesWafGroup', 'Service Web Application Firewall Policies Waf Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafGroup
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafGroup('ServiceWebApplicationFirewallPoliciesWafGroup', 'Service Web Application Firewall Policies Waf Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf.md <==
# ServiceWebApplicationFirewallPoliciesWaf


```text
azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf
```

```text
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')
```



| Illustration | ServiceWebApplicationFirewallPoliciesWaf | ServiceWebApplicationFirewallPoliciesWafCard | ServiceWebApplicationFirewallPoliciesWafGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf.png) | ![illustration for ServiceWebApplicationFirewallPoliciesWaf](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf.Local.png) | ![illustration for ServiceWebApplicationFirewallPoliciesWafCard](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWafCard.Local.png) | ![illustration for ServiceWebApplicationFirewallPoliciesWafGroup](../../../azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWafGroup.Local.png) |




## ServiceWebApplicationFirewallPoliciesWaf

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWaf
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWaf('ServiceWebApplicationFirewallPoliciesWaf', 'Service Web Application Firewall Policies Waf', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWaf
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWaf('ServiceWebApplicationFirewallPoliciesWaf', 'Service Web Application Firewall Policies Waf', 'an optional tech label')
@enduml
```

## ServiceWebApplicationFirewallPoliciesWafCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafCard
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafCard('ServiceWebApplicationFirewallPoliciesWafCard', 'Service Web Application Firewall Policies Waf Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafCard
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafCard('ServiceWebApplicationFirewallPoliciesWafCard', 'Service Web Application Firewall Policies Waf Card', 'an optional description')
@enduml
```

## ServiceWebApplicationFirewallPoliciesWafGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafGroup
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafGroup('ServiceWebApplicationFirewallPoliciesWafGroup', 'Service Web Application Firewall Policies Waf Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceWebApplicationFirewallPoliciesWafGroup
include('azure-4/Item/Networking/ServiceWebApplicationFirewallPoliciesWaf')

' renders the element
ServiceWebApplicationFirewallPoliciesWafGroup('ServiceWebApplicationFirewallPoliciesWafGroup', 'Service Web Application Firewall Policies Waf Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
